==> spring-boot-3.11.1-source-release.zip: spring-boot-3.11.1/core/camel-spring-boot/src/test/java/org/apache/camel/spring/boot/UuidGeneratorDiscoveryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.boot;

import java.util.UUID;

import org.apache.camel.CamelContext;
import org.apache.camel.spi.UuidGenerator;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.stereotype.Component;
import org.springframework.test.annotation.DirtiesContext;
import org.springframework.test.context.junit4.SpringRunner;

import static org.assertj.core.api.Assertions.assertThat;

@DirtiesContext
@RunWith(SpringRunner.class)
@SpringBootTest(
    classes = {
        CamelAutoConfiguration.class,
        UuidGeneratorDiscoveryTest.MyUuidGenerator.class
    }
)
public class UuidGeneratorDiscoveryTest {
    @Autowired
    private CamelContext camelContext;

    @Test
    public void testUuidDiscovery() {
        assertThat(camelContext.getUuidGenerator()).isInstanceOf(MyUuidGenerator.class);
    }

    @Component
    public static class MyUuidGenerator implements UuidGenerator {
        @Override
        public String generateUuid() {
            return UUID.randomUUID().toString();
        }
    }
}

==> spring-boot-3.20.7-source-release.zip: spring-boot-3.20.7/core/camel-spring-boot/src/test/java/org/apache/camel/spring/boot/UuidGeneratorDiscoveryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.boot;

import java.util.UUID;

import org.apache.camel.CamelContext;
import org.apache.camel.spi.UuidGenerator;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.stereotype.Component;
import org.springframework.test.annotation.DirtiesContext;
import org.apache.camel.test.spring.junit5.CamelSpringBootTest;

import static org.assertj.core.api.Assertions.assertThat;

@DirtiesContext
@CamelSpringBootTest
@SpringBootTest(
    classes = {
        CamelAutoConfiguration.class,
        UuidGeneratorDiscoveryTest.MyUuidGenerator.class
    }
)
public class UuidGeneratorDiscoveryTest {
    @Autowired
    private CamelContext camelContext;

    @Test
    public void testUuidDiscovery() {
        assertThat(camelContext.getUuidGenerator()).isInstanceOf(MyUuidGenerator.class);
    }

    @Component
    public static class MyUuidGenerator implements UuidGenerator {
        @Override
        public String generateUuid() {
            return UUID.randomUUID().toString();
        }
    }
}
